@@ -16,13 +16,12 @@ Including another URLconf
 from django.conf import settings
 from django.urls import path
 
-from .views import entity_list, fetch, resolve_entity_statement, trust_mark_status, advanced_entity_listing
+from .views import entity_list, fetch, trust_mark_status, advanced_entity_listing
 
 _PREF = getattr(settings, "OIDC_PREFIX", "")
 urlpatterns = [
     path(f"{_PREF}fetch/", fetch, name="oidcfed_fetch"),
     path(f"{_PREF}list/", entity_list, name="oidcfed_list"),
-    path(f"{_PREF}resolve/", resolve_entity_statement, name="oidcfed_resolve"),
     path(
         f"{_PREF}trust_mark_status/",
         trust_mark_status,
