@@ -38,7 +38,7 @@ def get_http_url(urls: list, httpc_params: dict = {}) -> list:
     if getattr(settings, "HTTP_CLIENT_SYNC", False):
         responses = []
         for i in urls:
-            res = requests.get(i, **httpc_params)
+            res = requests.get(i, **httpc_params) # nosec - B113
             responses.append(res.content.decode())
     else:
         responses = asyncio.run(http_get(urls, httpc_params)) # pragma: no cover
