@@ -13,7 +13,7 @@ try:
     OIDCFED_TRUST_ANCHORS = getattr(
         settings, "OIDCFED_TRUST_ANCHORS"
     )
-except AttributeError:
+except AttributeError: # pragma: no cover
     OIDCFED_TRUST_ANCHORS = []
     logger.warning(
         "OIDCFED_TRUST_ANCHORS not configured in your settings file."
@@ -45,6 +45,12 @@ class OnboardingRegistrationForm(forms.Form):
         },
     )
 
+    auth_request_url = forms.CharField(
+        initial="",
+        label=_("authentication request url"),
+        required = False
+    )
+
     contact = forms.EmailField(
         initial="",
         label=_("contact email"),
