@@ -36,20 +36,19 @@ op_conf = {
             ],
             "claims_supported": [
                 "https://attributes.spid.gov.it/spidCode",
-                "https://attributes.spid.gov.it/name",
-                "https://attributes.spid.gov.it/familyName",
-                "https://attributes.spid.gov.it/placeOfBirth",
-                "https://attributes.spid.gov.it/countyOfBirth",
-                "https://attributes.spid.gov.it/dateOfBirth",
-                "https://attributes.spid.gov.it/gender",
+                "given_name",
+                "family_name",
+                "place_of_birth",
+                "date_of_birth",
+                "gender",
                 "https://attributes.spid.gov.it/companyName",
                 "https://attributes.spid.gov.it/registeredOffice",
-                "https://attributes.spid.gov.it/fiscalNumber",
+                "https://attributes.spid.gov.it/fiscal_number",
                 "https://attributes.spid.gov.it/ivaCode",
                 "https://attributes.spid.gov.it/idCard",
                 "https://attributes.spid.gov.it/mobilePhone",
-                "https://attributes.spid.gov.it/email",
-                "https://attributes.spid.gov.it/address",
+                "email",
+                "address",
                 "https://attributes.spid.gov.it/expirationDate",
                 "https://attributes.spid.gov.it/digitalAddress",
             ],
@@ -136,4 +135,4 @@ op_conf = {
     },
     "constraints": {},
     "is_active": True,
-}
\ No newline at end of file
+}
